summaryrefslogtreecommitdiffstats
path: root/src/kernel
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel')
-rw-r--r--src/kernel/qdnd_x11.cpp2
-rw-r--r--src/kernel/qt_kernel.pri12
-rw-r--r--src/kernel/qt_pch.h2
-rw-r--r--src/kernel/qtaddons_x11.cpp2
-rw-r--r--src/kernel/tqabstractlayout.cpp2
-rw-r--r--src/kernel/tqaccel.cpp2
-rw-r--r--src/kernel/tqaccessible.cpp2
-rw-r--r--src/kernel/tqapplication.cpp (renamed from src/kernel/qapplication.cpp)14
-rw-r--r--src/kernel/tqapplication.h (renamed from src/kernel/ntqapplication.h)0
-rw-r--r--src/kernel/tqapplication_p.h (renamed from src/kernel/qapplication_p.h)2
-rw-r--r--src/kernel/tqapplication_x11.cpp (renamed from src/kernel/qapplication_x11.cpp)14
-rw-r--r--src/kernel/tqclipboard.cpp4
-rw-r--r--src/kernel/tqclipboard_x11.cpp12
-rw-r--r--src/kernel/tqcolor_x11.cpp4
-rw-r--r--src/kernel/tqcursor_x11.cpp2
-rw-r--r--src/kernel/tqdesktopwidget_x11.cpp4
-rw-r--r--src/kernel/tqdragobject.cpp2
-rw-r--r--src/kernel/tqdrawutil.cpp2
-rw-r--r--src/kernel/tqevent.cpp2
-rw-r--r--src/kernel/tqeventloop.cpp2
-rw-r--r--src/kernel/tqeventloop_unix.cpp2
-rw-r--r--src/kernel/tqeventloop_unix_glib.cpp2
-rw-r--r--src/kernel/tqeventloop_x11.cpp8
-rw-r--r--src/kernel/tqeventloop_x11_glib.cpp8
-rw-r--r--src/kernel/tqfont.cpp2
-rw-r--r--src/kernel/tqfont_x11.cpp2
-rw-r--r--src/kernel/tqfontdatabase.cpp4
-rw-r--r--src/kernel/tqiconset.cpp2
-rw-r--r--src/kernel/tqimage.cpp2
-rw-r--r--src/kernel/tqinputcontext.cpp2
-rw-r--r--src/kernel/tqinputcontext_x11.cpp2
-rw-r--r--src/kernel/tqlayout.cpp2
-rw-r--r--src/kernel/tqlocalfs.cpp2
-rw-r--r--src/kernel/tqmime.cpp2
-rw-r--r--src/kernel/tqmotifdnd_x11.cpp2
-rw-r--r--src/kernel/tqnamespace.h6
-rw-r--r--src/kernel/tqobject.cpp4
-rw-r--r--src/kernel/tqpaintdevice_x11.cpp2
-rw-r--r--src/kernel/tqpainter.cpp2
-rw-r--r--src/kernel/tqpixmap.cpp2
-rw-r--r--src/kernel/tqpixmap_x11.cpp6
-rw-r--r--src/kernel/tqprinter_unix.cpp2
-rw-r--r--src/kernel/tqprocess.cpp2
-rw-r--r--src/kernel/tqprocess_unix.cpp2
-rw-r--r--src/kernel/tqpsprinter.cpp2
-rw-r--r--src/kernel/tqrichtext.cpp2
-rw-r--r--src/kernel/tqrichtext_p.h2
-rw-r--r--src/kernel/tqsimplerichtext.cpp2
-rw-r--r--src/kernel/tqsizegrip.cpp4
-rw-r--r--src/kernel/tqsocketnotifier.cpp2
-rw-r--r--src/kernel/tqsound_x11.cpp2
-rw-r--r--src/kernel/tqstyle.cpp2
-rw-r--r--src/kernel/tqt3.h2
-rw-r--r--src/kernel/tqtextlayout.cpp2
-rw-r--r--src/kernel/tqthread.cpp2
-rw-r--r--src/kernel/tqthread_unix.cpp2
-rw-r--r--src/kernel/tqtimer.cpp2
-rw-r--r--src/kernel/tqtranslator.cpp2
-rw-r--r--src/kernel/tqurl.cpp2
-rw-r--r--src/kernel/tqwidget.cpp4
-rw-r--r--src/kernel/tqwidget_p.h2
-rw-r--r--src/kernel/tqwidget_x11.cpp20
62 files changed, 109 insertions, 109 deletions
diff --git a/src/kernel/qdnd_x11.cpp b/src/kernel/qdnd_x11.cpp
index 571045f48..57bdcffd4 100644
--- a/src/kernel/qdnd_x11.cpp
+++ b/src/kernel/qdnd_x11.cpp
@@ -40,7 +40,7 @@
#include "qplatformdefs.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#ifndef TQT_NO_DRAGANDDROP
diff --git a/src/kernel/qt_kernel.pri b/src/kernel/qt_kernel.pri
index 84a383a5d..05d5c8cd7 100644
--- a/src/kernel/qt_kernel.pri
+++ b/src/kernel/qt_kernel.pri
@@ -5,8 +5,8 @@ kernel {
HEADERS += \
$$KERNEL_H/tqaccel.h \
$$KERNEL_P/tqucomextra_p.h \
- $$KERNEL_H/ntqapplication.h \
- $$KERNEL_P/qapplication_p.h \
+ $$KERNEL_H/tqapplication.h \
+ $$KERNEL_P/tqapplication_p.h \
$$KERNEL_H/tqasyncimageio.h \
$$KERNEL_H/tqasyncio.h \
$$KERNEL_H/tqbitmap.h \
@@ -110,7 +110,7 @@ kernel {
HEADERS+=$$KERNEL_P/tqeventloop_glib_p.h
}
- win32:SOURCES += $$KERNEL_CPP/qapplication_win.cpp \
+ win32:SOURCES += $$KERNEL_CPP/tqapplication_win.cpp \
$$KERNEL_CPP/tqclipboard_win.cpp \
$$KERNEL_CPP/tqcolor_win.cpp \
$$KERNEL_CPP/tqcursor_win.cpp \
@@ -133,7 +133,7 @@ kernel {
$$KERNEL_CPP/tqfontengine_win.cpp
unix:x11 {
- SOURCES += $$KERNEL_CPP/qapplication_x11.cpp \
+ SOURCES += $$KERNEL_CPP/tqapplication_x11.cpp \
$$KERNEL_CPP/tqclipboard_x11.cpp \
$$KERNEL_CPP/tqcolor_x11.cpp \
$$KERNEL_CPP/tqcursor_x11.cpp \
@@ -163,7 +163,7 @@ kernel {
exists(tqsound_mac.cpp):SOURCES += $$KERNEL_CPP/tqsound_mac.cpp
}
!embedded:!x11:mac {
- SOURCES += $$KERNEL_CPP/qapplication_mac.cpp \
+ SOURCES += $$KERNEL_CPP/tqapplication_mac.cpp \
$$KERNEL_CPP/tqclipboard_mac.cpp \
$$KERNEL_CPP/tqcolor_mac.cpp \
$$KERNEL_CPP/tqcursor_mac.cpp \
@@ -196,7 +196,7 @@ kernel {
SOURCES += $$KERNEL_CPP/tqabstractlayout.cpp \
$$KERNEL_CPP/tqucomextra.cpp \
$$KERNEL_CPP/tqaccel.cpp \
- $$KERNEL_CPP/qapplication.cpp \
+ $$KERNEL_CPP/tqapplication.cpp \
$$KERNEL_CPP/tqasyncimageio.cpp \
$$KERNEL_CPP/tqasyncio.cpp \
$$KERNEL_CPP/tqbitmap.cpp \
diff --git a/src/kernel/qt_pch.h b/src/kernel/qt_pch.h
index 1420944ef..073f01b50 100644
--- a/src/kernel/qt_pch.h
+++ b/src/kernel/qt_pch.h
@@ -23,7 +23,7 @@
# endif
#include <tqmap.h> // I must be first!
#include <private/tqucomextra_p.h> // All moc genereated code has this include
-#include <ntqapplication.h>
+#include <tqapplication.h>
#include <tqbitmap.h>
#include <tqcursor.h>
#include <tqdatetime.h>
diff --git a/src/kernel/qtaddons_x11.cpp b/src/kernel/qtaddons_x11.cpp
index 089466ec7..c1d83e805 100644
--- a/src/kernel/qtaddons_x11.cpp
+++ b/src/kernel/qtaddons_x11.cpp
@@ -32,7 +32,7 @@
#include <string.h>
#include <stdlib.h>
-extern bool tqt_use_xrender; // defined in qapplication_x11.cpp
+extern bool tqt_use_xrender; // defined in tqapplication_x11.cpp
extern "C" {
diff --git a/src/kernel/tqabstractlayout.cpp b/src/kernel/tqabstractlayout.cpp
index 3f881ddbb..cbace549d 100644
--- a/src/kernel/tqabstractlayout.cpp
+++ b/src/kernel/tqabstractlayout.cpp
@@ -41,7 +41,7 @@
#include "tqlayout.h"
#ifndef TQT_NO_LAYOUT
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqlayoutengine_p.h"
#include "tqmenubar.h"
#include "tqtoolbar.h"
diff --git a/src/kernel/tqaccel.cpp b/src/kernel/tqaccel.cpp
index ef6b665e6..6569aa8dc 100644
--- a/src/kernel/tqaccel.cpp
+++ b/src/kernel/tqaccel.cpp
@@ -43,7 +43,7 @@
#ifndef TQT_NO_ACCEL
#include "tqsignal.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqwidget.h"
#include "tqptrlist.h"
#include "tqwhatsthis.h"
diff --git a/src/kernel/tqaccessible.cpp b/src/kernel/tqaccessible.cpp
index 5a43e402b..174e16633 100644
--- a/src/kernel/tqaccessible.cpp
+++ b/src/kernel/tqaccessible.cpp
@@ -43,7 +43,7 @@
#include "tqptrdict.h"
#include "tqmetaobject.h"
#include <private/tqpluginmanager_p.h>
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include <stdlib.h>
/*!
diff --git a/src/kernel/qapplication.cpp b/src/kernel/tqapplication.cpp
index db0fa0278..1cc5bf140 100644
--- a/src/kernel/qapplication.cpp
+++ b/src/kernel/tqapplication.cpp
@@ -39,7 +39,7 @@
**********************************************************************/
#include "tqobjectlist.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqeventloop.h"
#include "tqeventloop_p.h"
#include "tqwidget.h"
@@ -78,7 +78,7 @@
#endif
/*!
- \class TQApplication ntqapplication.h
+ \class TQApplication tqapplication.h
\brief The TQApplication class manages the GUI application's control
flow and main settings.
@@ -312,7 +312,7 @@
/*
The tqt_init() and tqt_cleanup() functions are implemented in the
- qapplication_xyz.cpp file.
+ tqapplication_xyz.cpp file.
*/
void tqt_init( int *, char **, TQApplication::Type );
@@ -1365,7 +1365,7 @@ TQApplication::~TQApplication()
\code
// showargs.cpp - displays program arguments in a list box
- #include <ntqapplication.h>
+ #include <tqapplication.h>
#include <tqlistbox.h>
int main( int argc, char **argv )
@@ -3155,7 +3155,7 @@ bool TQApplication::hasPendingEvents()
#if !defined(TQ_WS_X11)
-// The doc and X implementation of these functions is in qapplication_x11.cpp
+// The doc and X implementation of these functions is in tqapplication_x11.cpp
void TQApplication::flushX() {} // do nothing
@@ -4045,13 +4045,13 @@ TQ_EXPORT void tqt_dispatchEnterLeave( TQWidget* enter, TQWidget* leave ) {
#ifdef TQ_WS_MACX
-extern TQWidget *tqt_tryModalHelperMac( TQWidget * top ); //qapplication_mac.cpp
+extern TQWidget *tqt_tryModalHelperMac( TQWidget * top ); //tqapplication_mac.cpp
#endif
/*!\internal
- Called from qapplication_<platform>.cpp, returns TRUE
+ Called from tqapplication_<platform>.cpp, returns TRUE
if the widget should accept the event.
*/
TQ_EXPORT bool tqt_tryModalHelper( TQWidget *widget, TQWidget **rettop ) {
diff --git a/src/kernel/ntqapplication.h b/src/kernel/tqapplication.h
index 0e884583e..0e884583e 100644
--- a/src/kernel/ntqapplication.h
+++ b/src/kernel/tqapplication.h
diff --git a/src/kernel/qapplication_p.h b/src/kernel/tqapplication_p.h
index 08911eae7..742870dc3 100644
--- a/src/kernel/qapplication_p.h
+++ b/src/kernel/tqapplication_p.h
@@ -47,7 +47,7 @@
// -------------
//
// This file is not part of the TQt API. It exists for the convenience
-// of qapplication_*.cpp, tqwidget*.cpp, tqcolor_x11.cpp, tqfiledialog.cpp
+// of tqapplication_*.cpp, tqwidget*.cpp, tqcolor_x11.cpp, tqfiledialog.cpp
// and many other. This header file may change from version to version
// without notice, or even be removed.
//
diff --git a/src/kernel/qapplication_x11.cpp b/src/kernel/tqapplication_x11.cpp
index ec94e78b5..6744532f4 100644
--- a/src/kernel/qapplication_x11.cpp
+++ b/src/kernel/tqapplication_x11.cpp
@@ -42,7 +42,7 @@
// been in use (e.g. in the KDE wm ) before the introduction of a version
// map. One might want to turn some of them into propert public API and
// provide a proper alternative for others. See also the exports in
-// qapplication_win.cpp which suggest a unification.
+// tqapplication_win.cpp which suggest a unification.
#include "qplatformdefs.h"
@@ -61,8 +61,8 @@
# undef truncate
#endif
-#include "ntqapplication.h"
-#include "qapplication_p.h"
+#include "tqapplication.h"
+#include "tqapplication_p.h"
#include "tqcolor_p.h"
#include "tqcursor.h"
#include "tqwidget.h"
@@ -487,14 +487,14 @@ extern Atom qt_xdnd_finished;
extern Atom qt_xdnd_selection;
extern bool qt_xdnd_dragging;
-// gui or non-gui from qapplication.cpp
+// gui or non-gui from tqapplication.cpp
extern bool tqt_is_gui_used;
extern bool tqt_app_has_font;
static bool qt_x11_cmdline_font = false;
-extern bool tqt_resolve_symlinks; // from qapplication.cpp
+extern bool tqt_resolve_symlinks; // from tqapplication.cpp
// Paint event clipping magic
extern void qt_set_paintevent_clipping( TQPaintDevice* dev, const TQRegion& region);
@@ -1025,7 +1025,7 @@ bool TQApplication::x11_apply_settings()
}
// read new TQStyle
- extern bool tqt_explicit_app_style; // defined in qapplication.cpp
+ extern bool tqt_explicit_app_style; // defined in tqapplication.cpp
TQString stylename = settings.readEntry( "/qt/style" );
if ( !stylename.isEmpty() && !tqt_explicit_app_style ) {
TQApplication::setStyle( stylename );
@@ -6528,7 +6528,7 @@ void TQSmSocketReceiver::socketActivated(int)
#undef Bool
-#include "qapplication_x11.moc"
+#include "tqapplication_x11.moc"
TQSessionManager::TQSessionManager( TQApplication * app, TQString &id, TQString& key )
: TQObject( app, "session manager" )
diff --git a/src/kernel/tqclipboard.cpp b/src/kernel/tqclipboard.cpp
index f7c2836f5..ee476a1a5 100644
--- a/src/kernel/tqclipboard.cpp
+++ b/src/kernel/tqclipboard.cpp
@@ -42,8 +42,8 @@
#ifndef TQT_NO_CLIPBOARD
-#include "ntqapplication.h"
-#include "qapplication_p.h"
+#include "tqapplication.h"
+#include "tqapplication_p.h"
#include "tqdragobject.h"
#include "tqpixmap.h"
diff --git a/src/kernel/tqcolor_x11.cpp b/src/kernel/tqcolor_x11.cpp
index fe5f6685c..77f48037a 100644
--- a/src/kernel/tqcolor_x11.cpp
+++ b/src/kernel/tqcolor_x11.cpp
@@ -42,8 +42,8 @@
#include "tqcolor_p.h"
#include "string.h"
#include "tqpaintdevice.h"
-#include "ntqapplication.h"
-#include "qapplication_p.h"
+#include "tqapplication.h"
+#include "tqapplication_p.h"
#include "tqt_x11_p.h"
// NOT REVISED
diff --git a/src/kernel/tqcursor_x11.cpp b/src/kernel/tqcursor_x11.cpp
index 3724706c2..6a66e3cda 100644
--- a/src/kernel/tqcursor_x11.cpp
+++ b/src/kernel/tqcursor_x11.cpp
@@ -41,7 +41,7 @@
#include "tqcursor.h"
#include "tqbitmap.h"
#include "tqimage.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqdatastream.h"
#include "tqnamespace.h"
#include "tqt_x11_p.h"
diff --git a/src/kernel/tqdesktopwidget_x11.cpp b/src/kernel/tqdesktopwidget_x11.cpp
index 2a9e5bd9e..35d021c51 100644
--- a/src/kernel/tqdesktopwidget_x11.cpp
+++ b/src/kernel/tqdesktopwidget_x11.cpp
@@ -37,7 +37,7 @@
**********************************************************************/
#include "tqdesktopwidget.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqobjectlist.h"
#include "tqt_x11_p.h"
#include <cstdlib>
@@ -45,7 +45,7 @@
// defined in tqwidget_x11.cpp
extern int qt_x11_create_desktop_on_screen;
-// defined in qapplication_x11.cpp
+// defined in tqapplication_x11.cpp
extern Atom qt_net_workarea;
extern bool qt_net_supports(Atom atom);
diff --git a/src/kernel/tqdragobject.cpp b/src/kernel/tqdragobject.cpp
index b6fac2bd0..04b9f43a1 100644
--- a/src/kernel/tqdragobject.cpp
+++ b/src/kernel/tqdragobject.cpp
@@ -47,7 +47,7 @@
#include "tqdragobject.h"
#include "tqtextcodec.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqpoint.h"
#include "tqwidget.h"
#include "tqbuffer.h"
diff --git a/src/kernel/tqdrawutil.cpp b/src/kernel/tqdrawutil.cpp
index 0c3283ddc..79aa69378 100644
--- a/src/kernel/tqdrawutil.cpp
+++ b/src/kernel/tqdrawutil.cpp
@@ -42,7 +42,7 @@
#ifndef TQT_NO_DRAWUTIL
#include "tqbitmap.h"
#include "tqpixmapcache.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqpainter.h"
/*!
diff --git a/src/kernel/tqevent.cpp b/src/kernel/tqevent.cpp
index e8d042b06..fc59d9164 100644
--- a/src/kernel/tqevent.cpp
+++ b/src/kernel/tqevent.cpp
@@ -40,7 +40,7 @@
#include "tqevent.h"
#include "tqcursor.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
/*!
diff --git a/src/kernel/tqeventloop.cpp b/src/kernel/tqeventloop.cpp
index 3a7d72833..0cc3036d6 100644
--- a/src/kernel/tqeventloop.cpp
+++ b/src/kernel/tqeventloop.cpp
@@ -38,7 +38,7 @@
#include "tqeventloop_p.h" // includes qplatformdefs.h
#include "tqeventloop.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqdatetime.h"
#ifdef TQT_THREAD_SUPPORT
diff --git a/src/kernel/tqeventloop_unix.cpp b/src/kernel/tqeventloop_unix.cpp
index 8ab816426..fc0a0b48b 100644
--- a/src/kernel/tqeventloop_unix.cpp
+++ b/src/kernel/tqeventloop_unix.cpp
@@ -38,7 +38,7 @@
#include "tqeventloop_p.h" // includes qplatformdefs.h
#include "tqeventloop.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqbitarray.h"
#include "tqmutex.h"
#include <stdlib.h>
diff --git a/src/kernel/tqeventloop_unix_glib.cpp b/src/kernel/tqeventloop_unix_glib.cpp
index 200c9245d..eec66d0af 100644
--- a/src/kernel/tqeventloop_unix_glib.cpp
+++ b/src/kernel/tqeventloop_unix_glib.cpp
@@ -38,7 +38,7 @@
#include "tqeventloop_glib_p.h" // includes qplatformdefs.h
#include "tqeventloop.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqbitarray.h"
#include "tqmutex.h"
diff --git a/src/kernel/tqeventloop_x11.cpp b/src/kernel/tqeventloop_x11.cpp
index 743d48e70..13ba8c6af 100644
--- a/src/kernel/tqeventloop_x11.cpp
+++ b/src/kernel/tqeventloop_x11.cpp
@@ -38,7 +38,7 @@
#include "tqeventloop_p.h" // includes qplatformdefs.h
#include "tqeventloop.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqbitarray.h"
#include "tqcolor_p.h"
#include "tqt_x11_p.h"
@@ -59,7 +59,7 @@ static const int XKeyRelease = KeyRelease;
#undef KeyPress
#undef KeyRelease
-// from qapplication.cpp
+// from tqapplication.cpp
extern bool tqt_is_gui_used;
// from tqeventloop_unix.cpp
@@ -170,7 +170,7 @@ bool TQEventLoop::processEvents( ProcessEventsFlags flags )
case ClientMessage:
{
- // from qapplication_x11.cpp
+ // from tqapplication_x11.cpp
extern Atom tqt_wm_protocols;
extern Atom tqt_wm_take_focus;
extern Atom qt_qt_scrolldone;
@@ -405,7 +405,7 @@ bool TQEventLoop::processEvents( ProcessEventsFlags flags )
bool TQEventLoop::hasPendingEvents() const
{
- extern uint qGlobalPostedEventsCount(); // from qapplication.cpp
+ extern uint qGlobalPostedEventsCount(); // from tqapplication.cpp
return ( qGlobalPostedEventsCount() || XPending( TQPaintDevice::x11AppDisplay() ) );
}
diff --git a/src/kernel/tqeventloop_x11_glib.cpp b/src/kernel/tqeventloop_x11_glib.cpp
index 28069fe1b..cf2126591 100644
--- a/src/kernel/tqeventloop_x11_glib.cpp
+++ b/src/kernel/tqeventloop_x11_glib.cpp
@@ -41,7 +41,7 @@
#include "tqeventloop_glib_p.h" // includes qplatformdefs.h
#include "tqeventloop.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqbitarray.h"
#include "tqcolor_p.h"
#include "tqt_x11_p.h"
@@ -140,7 +140,7 @@ static const int XKeyRelease = KeyRelease;
#undef KeyPress
#undef KeyRelease
-// from qapplication.cpp
+// from tqapplication.cpp
extern bool tqt_is_gui_used;
// from tqeventloop_unix.cpp
@@ -339,7 +339,7 @@ bool TQEventLoop::processX11Events()
case ClientMessage:
{
- // from qapplication_x11.cpp
+ // from tqapplication_x11.cpp
extern Atom tqt_wm_protocols;
extern Atom tqt_wm_take_focus;
extern Atom qt_qt_scrolldone;
@@ -645,7 +645,7 @@ bool TQEventLoop::hasPendingEvents() const
TQMutexLocker locker( TQApplication::tqt_mutex );
#endif // TQT_THREAD_SUPPORT
- extern uint qGlobalPostedEventsCount(); // from qapplication.cpp
+ extern uint qGlobalPostedEventsCount(); // from tqapplication.cpp
return ( qGlobalPostedEventsCount() || ( (tqt_is_gui_used && TQApplication::isGuiThread()) ? XPending( TQPaintDevice::x11AppDisplay() ) : 0));
}
diff --git a/src/kernel/tqfont.cpp b/src/kernel/tqfont.cpp
index e058e49d4..c8395d342 100644
--- a/src/kernel/tqfont.cpp
+++ b/src/kernel/tqfont.cpp
@@ -48,7 +48,7 @@
#include "tqdict.h"
#include "tqcache.h"
#include "tqdatastream.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqcleanuphandler.h"
#include "tqstringlist.h"
#ifdef TQ_WS_MAC
diff --git a/src/kernel/tqfont_x11.cpp b/src/kernel/tqfont_x11.cpp
index 373a82a5f..77742a5f0 100644
--- a/src/kernel/tqfont_x11.cpp
+++ b/src/kernel/tqfont_x11.cpp
@@ -45,7 +45,7 @@
#include "qplatformdefs.h"
#include "tqfont.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqcleanuphandler.h"
#include "tqfontinfo.h"
#include "tqfontdatabase.h"
diff --git a/src/kernel/tqfontdatabase.cpp b/src/kernel/tqfontdatabase.cpp
index 0702bb67f..5413f2db4 100644
--- a/src/kernel/tqfontdatabase.cpp
+++ b/src/kernel/tqfontdatabase.cpp
@@ -43,7 +43,7 @@
#ifndef TQT_NO_FONTDATABASE
#include <tqtl.h>
-#include <ntqapplication.h>
+#include <tqapplication.h>
#include <private/tqunicodetables_p.h>
#include "tqfontengine_p.h"
@@ -1330,7 +1330,7 @@ TQString TQFontDatabase::styleString( const TQFont &f )
Example:
\code
-#include <ntqapplication.h>
+#include <tqapplication.h>
#include <tqfontdatabase.h>
#include <else.h>
diff --git a/src/kernel/tqiconset.cpp b/src/kernel/tqiconset.cpp
index 2a251c2ff..22e8a8f1d 100644
--- a/src/kernel/tqiconset.cpp
+++ b/src/kernel/tqiconset.cpp
@@ -42,7 +42,7 @@
#ifndef TQT_NO_ICONSET
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqbitmap.h"
#include "tqcleanuphandler.h"
#include "tqimage.h"
diff --git a/src/kernel/tqimage.cpp b/src/kernel/tqimage.cpp
index 50ed52222..177c0a6af 100644
--- a/src/kernel/tqimage.cpp
+++ b/src/kernel/tqimage.cpp
@@ -53,7 +53,7 @@
#include <private/tqpluginmanager_p.h>
#include "tqimageformatinterface_p.h"
#include "tqwmatrix.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqmime.h"
#include "tqdragobject.h"
#include <ctype.h>
diff --git a/src/kernel/tqinputcontext.cpp b/src/kernel/tqinputcontext.cpp
index 7d15aa0c7..7f0d5501d 100644
--- a/src/kernel/tqinputcontext.cpp
+++ b/src/kernel/tqinputcontext.cpp
@@ -41,7 +41,7 @@
#include "qplatformdefs.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqwidget.h"
#include "tqpopupmenu.h"
diff --git a/src/kernel/tqinputcontext_x11.cpp b/src/kernel/tqinputcontext_x11.cpp
index 7377b264c..70fa9f160 100644
--- a/src/kernel/tqinputcontext_x11.cpp
+++ b/src/kernel/tqinputcontext_x11.cpp
@@ -42,7 +42,7 @@
#include "qplatformdefs.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqwidget.h"
#include "tqt_x11_p.h"
diff --git a/src/kernel/tqlayout.cpp b/src/kernel/tqlayout.cpp
index bfab60480..814f1565b 100644
--- a/src/kernel/tqlayout.cpp
+++ b/src/kernel/tqlayout.cpp
@@ -42,7 +42,7 @@
#ifndef TQT_NO_LAYOUT
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqwidget.h"
#include "tqptrlist.h"
#include "tqsizepolicy.h"
diff --git a/src/kernel/tqlocalfs.cpp b/src/kernel/tqlocalfs.cpp
index 5adc77fb2..69e2eba72 100644
--- a/src/kernel/tqlocalfs.cpp
+++ b/src/kernel/tqlocalfs.cpp
@@ -45,7 +45,7 @@
#include "tqfileinfo.h"
#include "tqfile.h"
#include "tqurlinfo.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqurloperator.h"
#include "tqguardedptr.h"
diff --git a/src/kernel/tqmime.cpp b/src/kernel/tqmime.cpp
index d230d88d8..ba12e4c8e 100644
--- a/src/kernel/tqmime.cpp
+++ b/src/kernel/tqmime.cpp
@@ -46,7 +46,7 @@
#include "tqdir.h"
#include "tqdragobject.h"
#include "tqcleanuphandler.h"
-#include "ntqapplication.h" // ### for now
+#include "tqapplication.h" // ### for now
#include "tqclipboard.h" // ### for now
/*!
diff --git a/src/kernel/tqmotifdnd_x11.cpp b/src/kernel/tqmotifdnd_x11.cpp
index cf5867aeb..e1481446f 100644
--- a/src/kernel/tqmotifdnd_x11.cpp
+++ b/src/kernel/tqmotifdnd_x11.cpp
@@ -68,7 +68,7 @@ in doc/dnd.doc, where the documentation system can see it. */
#include "qplatformdefs.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#ifndef TQT_NO_DRAGANDDROP
diff --git a/src/kernel/tqnamespace.h b/src/kernel/tqnamespace.h
index f5ec7dd1d..4ff686c1c 100644
--- a/src/kernel/tqnamespace.h
+++ b/src/kernel/tqnamespace.h
@@ -814,7 +814,7 @@ public:
CustomPattern=24
};
- // documented in qapplication_mac.cpp
+ // documented in tqapplication_mac.cpp
enum MacintoshVersion {
//Unknown
MV_Unknown = 0x0000,
@@ -835,7 +835,7 @@ public:
MV_TIGER = MV_10_DOT_4
};
- // documented in qapplication_win.cpp
+ // documented in tqapplication_win.cpp
enum WindowsVersion {
WV_32s = 0x0001,
WV_95 = 0x0002,
@@ -1005,7 +1005,7 @@ public:
};
// "handle" type for system objects. Documented as \internal in
- // qapplication.cpp
+ // tqapplication.cpp
#if defined(TQ_WS_MAC)
typedef void * HANDLE;
#elif defined(TQ_WS_WIN)
diff --git a/src/kernel/tqobject.cpp b/src/kernel/tqobject.cpp
index 85c69f8ba..e37cf1481 100644
--- a/src/kernel/tqobject.cpp
+++ b/src/kernel/tqobject.cpp
@@ -39,7 +39,7 @@
**********************************************************************/
#include "tqvariant.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqobject.h"
#include "tqobjectlist.h"
#include "tqsignalslotimp.h"
@@ -454,7 +454,7 @@ static TQCString qt_rmWS( const char *s )
}
-// Event functions, implemented in qapplication_xxx.cpp
+// Event functions, implemented in tqapplication_xxx.cpp
int qStartTimer( int interval, TQObject *obj );
bool qKillTimer( int id );
diff --git a/src/kernel/tqpaintdevice_x11.cpp b/src/kernel/tqpaintdevice_x11.cpp
index 37bdfa83e..efeaf78fa 100644
--- a/src/kernel/tqpaintdevice_x11.cpp
+++ b/src/kernel/tqpaintdevice_x11.cpp
@@ -43,7 +43,7 @@
#include "tqpainter.h"
#include "tqwidget.h"
#include "tqbitmap.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqt_x11_p.h"
diff --git a/src/kernel/tqpainter.cpp b/src/kernel/tqpainter.cpp
index b66f16d2b..452af0a57 100644
--- a/src/kernel/tqpainter.cpp
+++ b/src/kernel/tqpainter.cpp
@@ -47,7 +47,7 @@
#include "tqwidget.h"
#include "tqimage.h"
#include "tqpaintdevicemetrics.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqrichtext_p.h"
#include "tqregexp.h"
#include "tqcleanuphandler.h"
diff --git a/src/kernel/tqpixmap.cpp b/src/kernel/tqpixmap.cpp
index 4a40d821b..c3eceba6b 100644
--- a/src/kernel/tqpixmap.cpp
+++ b/src/kernel/tqpixmap.cpp
@@ -47,7 +47,7 @@
#include "tqdatastream.h"
#include "tqbuffer.h"
#include "tqobjectlist.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include <private/tqinternal_p.h>
#include "tqmime.h"
#include "tqdragobject.h"
diff --git a/src/kernel/tqpixmap_x11.cpp b/src/kernel/tqpixmap_x11.cpp
index 9f8c6b7d1..36c050005 100644
--- a/src/kernel/tqpixmap_x11.cpp
+++ b/src/kernel/tqpixmap_x11.cpp
@@ -71,7 +71,7 @@
#include "tqpaintdevicemetrics.h"
#include "tqimage.h"
#include "tqwmatrix.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqt_x11_p.h"
#include <stdlib.h>
@@ -371,7 +371,7 @@ static void build_scale_table( uint **table, uint nBits )
static int defaultScreen = -1;
-extern bool tqt_use_xrender; // defined in qapplication_x11.cpp
+extern bool tqt_use_xrender; // defined in tqapplication_x11.cpp
extern bool tqt_has_xft; // defined in tqfont_x11.cpp
#ifndef TQT_NO_XFTFREETYPE
@@ -2421,7 +2421,7 @@ TQ_EXPORT void copyBlt( TQPixmap *dst, int dx, int dy,
#ifndef TQT_NO_XFTFREETYPE
// copy alpha data
- extern bool tqt_use_xrender; // from qapplication_x11.cpp
+ extern bool tqt_use_xrender; // from tqapplication_x11.cpp
if ( ! tqt_use_xrender || ! src->data->alphapm )
return;
diff --git a/src/kernel/tqprinter_unix.cpp b/src/kernel/tqprinter_unix.cpp
index 2899d86df..e53dc5ff6 100644
--- a/src/kernel/tqprinter_unix.cpp
+++ b/src/kernel/tqprinter_unix.cpp
@@ -54,7 +54,7 @@ static inline int qt_open(const char *pathname, int flags, mode_t mode)
#include "tqpaintdevicemetrics.h"
#include "tqpsprinter_p.h"
#include "tqprintdialog.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqprinter_p.h"
#include <unistd.h> // For ::sleep()
diff --git a/src/kernel/tqprocess.cpp b/src/kernel/tqprocess.cpp
index bfca757a8..b43c12b4a 100644
--- a/src/kernel/tqprocess.cpp
+++ b/src/kernel/tqprocess.cpp
@@ -45,7 +45,7 @@
#ifndef TQT_NO_PROCESS
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "private/tqinternal_p.h"
diff --git a/src/kernel/tqprocess_unix.cpp b/src/kernel/tqprocess_unix.cpp
index b9a79afda..606d1fd28 100644
--- a/src/kernel/tqprocess_unix.cpp
+++ b/src/kernel/tqprocess_unix.cpp
@@ -49,7 +49,7 @@
#ifndef TQT_NO_PROCESS
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqptrqueue.h"
#include "tqptrlist.h"
#include "tqsocketnotifier.h"
diff --git a/src/kernel/tqpsprinter.cpp b/src/kernel/tqpsprinter.cpp
index 80e00ae23..bc283807c 100644
--- a/src/kernel/tqpsprinter.cpp
+++ b/src/kernel/tqpsprinter.cpp
@@ -57,7 +57,7 @@
#undef Q_PRINTER_USE_TYPE42
#include "tqpainter.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqpaintdevicemetrics.h"
#include "tqimage.h"
#include "tqdatetime.h"
diff --git a/src/kernel/tqrichtext.cpp b/src/kernel/tqrichtext.cpp
index 9866a6c9c..57b091721 100644
--- a/src/kernel/tqrichtext.cpp
+++ b/src/kernel/tqrichtext.cpp
@@ -47,7 +47,7 @@
#include "tqfont.h"
#include "tqtextstream.h"
#include "tqfile.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqmap.h"
#include "tqfileinfo.h"
#include "tqstylesheet.h"
diff --git a/src/kernel/tqrichtext_p.h b/src/kernel/tqrichtext_p.h
index 1032c74eb..11dfcc6d1 100644
--- a/src/kernel/tqrichtext_p.h
+++ b/src/kernel/tqrichtext_p.h
@@ -74,7 +74,7 @@
#include "tqpainter.h"
#include "tqlayout.h"
#include "tqobject.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#endif // QT_H
#ifndef TQT_NO_RICHTEXT
diff --git a/src/kernel/tqsimplerichtext.cpp b/src/kernel/tqsimplerichtext.cpp
index 4c98f1fd3..c2808b1cd 100644
--- a/src/kernel/tqsimplerichtext.cpp
+++ b/src/kernel/tqsimplerichtext.cpp
@@ -42,7 +42,7 @@
#ifndef TQT_NO_RICHTEXT
#include "tqrichtext_p.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
class TQSimpleRichTextData
{
diff --git a/src/kernel/tqsizegrip.cpp b/src/kernel/tqsizegrip.cpp
index 017c3e6a0..65b29a1c9 100644
--- a/src/kernel/tqsizegrip.cpp
+++ b/src/kernel/tqsizegrip.cpp
@@ -43,12 +43,12 @@
#ifndef TQT_NO_SIZEGRIP
#include "tqpainter.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqstyle.h"
#if defined(TQ_WS_X11)
#include "tqt_x11_p.h"
-extern Atom qt_sizegrip; // defined in qapplication_x11.cpp
+extern Atom qt_sizegrip; // defined in tqapplication_x11.cpp
#elif defined (TQ_WS_WIN )
#include "tqobjectlist.h"
#include "qt_windows.h"
diff --git a/src/kernel/tqsocketnotifier.cpp b/src/kernel/tqsocketnotifier.cpp
index b350403a5..3a3d32a07 100644
--- a/src/kernel/tqsocketnotifier.cpp
+++ b/src/kernel/tqsocketnotifier.cpp
@@ -39,7 +39,7 @@
**********************************************************************/
#include "tqsocketnotifier.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqevent.h"
#include "tqeventloop.h"
#include "qplatformdefs.h"
diff --git a/src/kernel/tqsound_x11.cpp b/src/kernel/tqsound_x11.cpp
index bbdbf5b44..dba19b144 100644
--- a/src/kernel/tqsound_x11.cpp
+++ b/src/kernel/tqsound_x11.cpp
@@ -44,7 +44,7 @@
#include "tqptrdict.h"
#include "tqsocketnotifier.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#ifdef QT_NAS_SUPPORT
diff --git a/src/kernel/tqstyle.cpp b/src/kernel/tqstyle.cpp
index dfa1c2cbe..27a4ce33c 100644
--- a/src/kernel/tqstyle.cpp
+++ b/src/kernel/tqstyle.cpp
@@ -40,7 +40,7 @@
#include "tqstyle.h"
#ifndef TQT_NO_STYLE
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqpainter.h"
#include "tqbitmap.h"
#include "tqpixmapcache.h"
diff --git a/src/kernel/tqt3.h b/src/kernel/tqt3.h
index cff4b0895..9300c254e 100644
--- a/src/kernel/tqt3.h
+++ b/src/kernel/tqt3.h
@@ -258,7 +258,7 @@
#include <tqvgroupbox.h>
#include <tqthread.h>
#include <tqwhatsthis.h>
-#include <ntqapplication.h>
+#include <tqapplication.h>
#include <tqwidgetintdict.h>
#include <tqfocusdata.h>
#include <tqwidgetplugin.h>
diff --git a/src/kernel/tqtextlayout.cpp b/src/kernel/tqtextlayout.cpp
index 3e71ccd39..0d50e4106 100644
--- a/src/kernel/tqtextlayout.cpp
+++ b/src/kernel/tqtextlayout.cpp
@@ -40,7 +40,7 @@
#include "tqtextengine_p.h"
#include <tqfont.h>
-#include <ntqapplication.h>
+#include <tqapplication.h>
#include <tqpainter.h>
diff --git a/src/kernel/tqthread.cpp b/src/kernel/tqthread.cpp
index 560577589..9a1d1f602 100644
--- a/src/kernel/tqthread.cpp
+++ b/src/kernel/tqthread.cpp
@@ -45,7 +45,7 @@
#include <private/tqthreadinstance_p.h>
#ifndef QT_H
-# include "ntqapplication.h"
+# include "tqapplication.h"
#endif // QT_H
diff --git a/src/kernel/tqthread_unix.cpp b/src/kernel/tqthread_unix.cpp
index db780ee18..714b35c31 100644
--- a/src/kernel/tqthread_unix.cpp
+++ b/src/kernel/tqthread_unix.cpp
@@ -47,7 +47,7 @@ typedef pthread_mutex_t Q_MUTEX_T;
#include <private/tqmutex_p.h>
#include <private/tqmutexpool_p.h>
#include <tqthreadstorage.h>
-#include <ntqapplication.h>
+#include <tqapplication.h>
#include <errno.h>
#include <sched.h>
diff --git a/src/kernel/tqtimer.cpp b/src/kernel/tqtimer.cpp
index 3d19923e8..84803f1b5 100644
--- a/src/kernel/tqtimer.cpp
+++ b/src/kernel/tqtimer.cpp
@@ -302,7 +302,7 @@ bool TQSingleShotTimer::event( TQEvent * )
Example:
\code
- #include <ntqapplication.h>
+ #include <tqapplication.h>
#include <tqtimer.h>
int main( int argc, char **argv )
diff --git a/src/kernel/tqtranslator.cpp b/src/kernel/tqtranslator.cpp
index fd86a73ca..b6a11feb3 100644
--- a/src/kernel/tqtranslator.cpp
+++ b/src/kernel/tqtranslator.cpp
@@ -60,7 +60,7 @@ static inline int qt_open(const char *pathname, int flags, mode_t mode)
#include "tqwidgetlist.h"
#include "tqintdict.h"
#include "tqstring.h"
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqfile.h"
#include "tqbuffer.h"
#include "tqdatastream.h"
diff --git a/src/kernel/tqurl.cpp b/src/kernel/tqurl.cpp
index 1155e9fa1..7d0066f0c 100644
--- a/src/kernel/tqurl.cpp
+++ b/src/kernel/tqurl.cpp
@@ -1010,7 +1010,7 @@ void TQUrl::setEncodedPathAndQuery( const TQString& pathAndQuery )
d->cleanPathDirty = TRUE;
}
-extern bool tqt_resolve_symlinks; // defined in qapplication.cpp
+extern bool tqt_resolve_symlinks; // defined in tqapplication.cpp
/*!
Returns the path of the URL. If \a correct is TRUE, the path is
diff --git a/src/kernel/tqwidget.cpp b/src/kernel/tqwidget.cpp
index 33c4768a6..71fe8ea16 100644
--- a/src/kernel/tqwidget.cpp
+++ b/src/kernel/tqwidget.cpp
@@ -47,8 +47,8 @@
#include "tqfocusdata.h"
#include "tqcursor.h"
#include "tqpixmap.h"
-#include "ntqapplication.h"
-#include "qapplication_p.h"
+#include "tqapplication.h"
+#include "tqapplication_p.h"
#include "tqbrush.h"
#include "tqlayout.h"
#include "tqstylefactory.h"
diff --git a/src/kernel/tqwidget_p.h b/src/kernel/tqwidget_p.h
index 0c0eb9460..6815665c2 100644
--- a/src/kernel/tqwidget_p.h
+++ b/src/kernel/tqwidget_p.h
@@ -47,7 +47,7 @@
// -------------
//
// This file is not part of the TQt API. It exists for the convenience
-// of qapplication_*.cpp, tqwidget*.cpp and tqfiledialog.cpp. This header
+// of tqapplication_*.cpp, tqwidget*.cpp and tqfiledialog.cpp. This header
// file may change from version to version without notice, or even be removed.
//
// We mean it.
diff --git a/src/kernel/tqwidget_x11.cpp b/src/kernel/tqwidget_x11.cpp
index 2f90c4905..c8492c6e6 100644
--- a/src/kernel/tqwidget_x11.cpp
+++ b/src/kernel/tqwidget_x11.cpp
@@ -38,8 +38,8 @@
**
**********************************************************************/
-#include "ntqapplication.h"
-#include "qapplication_p.h"
+#include "tqapplication.h"
+#include "tqapplication_p.h"
#include "tqnamespace.h"
#include "tqpaintdevicemetrics.h"
#include "tqpainter.h"
@@ -55,11 +55,11 @@
// NOT REVISED
-// defined in qapplication_x11.cpp
+// defined in tqapplication_x11.cpp
extern Window qt_x11_wm_client_leader;
extern void qt_x11_create_wm_client_leader();
-// defined in qapplication_x11.cpp
+// defined in tqapplication_x11.cpp
void qt_insert_sip( TQWidget*, int, int );
int qt_sip_count( TQWidget* );
bool qt_wstate_iconified( WId );
@@ -77,7 +77,7 @@ extern void qt_clear_paintevent_clipping();
extern bool qt_dnd_enable( TQWidget* w, bool on );
extern bool qt_nograb();
-// defined in qapplication_x11.cpp
+// defined in tqapplication_x11.cpp
extern void qt_deferred_map_add( TQWidget* );
extern void qt_deferred_map_take( TQWidget* );
extern bool qt_deferred_map_contains(TQWidget *);
@@ -85,7 +85,7 @@ extern bool qt_deferred_map_contains(TQWidget *);
static TQWidget *mouseGrb = 0;
static TQWidget *keyboardGrb = 0;
-// defined in qapplication_x11.cpp
+// defined in tqapplication_x11.cpp
extern Time tqt_x_time;
extern Time tqt_x_user_time;
@@ -104,7 +104,7 @@ int qt_x11_create_desktop_on_screen = -1;
TQWidget member functions
*****************************************************************************/
-// defined in qapplication_x11.cpp
+// defined in tqapplication_x11.cpp
extern Atom tqt_wm_state;
extern Atom qt_wm_change_state;
extern Atom tqt_wm_delete_window;
@@ -157,7 +157,7 @@ extern Atom qt_enlightenment_desktop;
extern Atom qt_net_virtual_roots;
extern bool qt_broken_wm;
-// defined in qapplication_x11.cpp
+// defined in tqapplication_x11.cpp
extern bool qt_net_supports(Atom);
extern unsigned long *qt_net_virtual_root_list;
@@ -835,7 +835,7 @@ void TQWidget::destroy( bool destroyWindow, bool destroySubWindows )
#endif
setWinId( 0 );
- extern void qPRCleanup( TQWidget *widget ); // from qapplication_x11.cpp
+ extern void qPRCleanup( TQWidget *widget ); // from tqapplication_x11.cpp
if ( testWState(WState_Reparented) )
qPRCleanup(this);
@@ -2228,7 +2228,7 @@ void TQWidget::internalSetGeometry( int x, int y, int w, int h, bool isMove )
}
if ( isResize ) {
- // set config pending only on resize, see qapplication_x11.cpp, translateConfigEvent()
+ // set config pending only on resize, see tqapplication_x11.cpp, translateConfigEvent()
setWState( WState_ConfigPending );
TQResizeEvent e( size(), oldSize );
diff --git a/src/kernel/tqclipboard_x11.cpp b/src/kernel/tqclipboard_x11.cpp
index 16af49f8e..16772b491 100644
--- a/src/kernel/tqclipboard_x11.cpp
+++ b/src/kernel/tqclipboard_x11.cpp
@@ -64,7 +64,7 @@
#ifndef TQT_NO_CLIPBOARD
-#include "ntqapplication.h"
+#include "tqapplication.h"
#include "tqeventloop.h"
#include "tqbitmap.h"
#include "tqdatetime.h"
@@ -74,7 +74,7 @@
#include "tqvaluelist.h"
#include "tqmap.h"
#include "tqt_x11_p.h"
-#include "qapplication_p.h"
+#include "tqapplication_p.h"
// REVISED: arnt
@@ -83,12 +83,12 @@
Internal TQClipboard functions for X11.
*****************************************************************************/
-// from qapplication_x11.cpp
+// from tqapplication_x11.cpp
typedef int (*QX11EventFilter) (XEvent*);
extern QX11EventFilter tqt_set_x11_event_filter (QX11EventFilter filter);
-extern Time tqt_x_time; // def. in qapplication_x11.cpp
-extern Time qt_x_incr; // def. in qapplication_x11.cpp
+extern Time tqt_x_time; // def. in tqapplication_x11.cpp
+extern Time qt_x_incr; // def. in tqapplication_x11.cpp
extern Atom qt_xa_clipboard;
extern Atom qt_selection_property;
extern Atom tqt_clipboard_sentinel;
@@ -1575,7 +1575,7 @@ void TQClipboard::setData( TQMimeSource* src, Mode mode )
/*
- Called by the main event loop in qapplication_x11.cpp when the
+ Called by the main event loop in tqapplication_x11.cpp when the
_QT_SELECTION_SENTINEL property has been changed (i.e. when some TQt
process has performed TQClipboard::setData(). If it returns TRUE, the
TQClipBoard dataChanged() signal should be emitted.